@@ -1,14 +1,20 @@
-( cd usr/man/man8 ; rm -rf mount.ntfs-3g.8.gz )
-( cd usr/man/man8 ; ln -sf ntfs-3g.8.gz mount.ntfs-3g.8.gz )
-( cd usr/man/man8 ; rm -rf mount.lowntfs-3g.8.gz )
-( cd usr/man/man8 ; ln -sf ntfs-3g.8.gz mount.lowntfs-3g.8.gz )
-( cd usr/lib ; rm -rf libntfs-3g.so )
-( cd usr/lib ; ln -sf /lib/libntfs-3g.so libntfs-3g.so )
 ( cd lib ; rm -rf libntfs-3g.so )
-( cd lib ; ln -sf libntfs-3g.so.80.0.0 libntfs-3g.so )
-( cd lib ; rm -rf libntfs-3g.so.80 )
-( cd lib ; ln -sf libntfs-3g.so.80.0.0 libntfs-3g.so.80 )
+( cd lib ; ln -sf libntfs-3g.so.84.0.0 libntfs-3g.so )
+( cd lib ; rm -rf libntfs-3g.so.84 )
+( cd lib ; ln -sf libntfs-3g.so.84.0.0 libntfs-3g.so.84 )
 ( cd sbin ; rm -rf mount.lowntfs-3g )
 ( cd sbin ; ln -sf /bin/lowntfs-3g mount.lowntfs-3g )
+( cd sbin ; rm -rf mkfs.ntfs )
+( cd sbin ; ln -sf /sbin/mkntfs mkfs.ntfs )
+( cd sbin ; rm -rf mount.ntfs )
+( cd sbin ; ln -sf mount.ntfs-3g mount.ntfs )
 ( cd sbin ; rm -rf mount.ntfs-3g )
 ( cd sbin ; ln -sf /bin/ntfs-3g mount.ntfs-3g )
+( cd usr/lib ; rm -rf libntfs-3g.so )
+( cd usr/lib ; ln -sf /lib/libntfs-3g.so libntfs-3g.so )
+( cd usr/man/man8 ; rm -rf mount.lowntfs-3g.8.gz )
+( cd usr/man/man8 ; ln -sf ntfs-3g.8.gz mount.lowntfs-3g.8.gz )
+( cd usr/man/man8 ; rm -rf mkfs.ntfs.8.gz )
+( cd usr/man/man8 ; ln -sf mkntfs.8.gz mkfs.ntfs.8.gz )
+( cd usr/man/man8 ; rm -rf mount.ntfs-3g.8.gz )
+( cd usr/man/man8 ; ln -sf ntfs-3g.8.gz mount.ntfs-3g.8.gz )
